@@ -6,20 +6,18 @@ describe 'manila::network::neutron' do
       it 'configures manila network neutron' do
         is_expected.to contain_manila_config('neutron/insecure').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('neutron/auth_url').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_manila_config('neutron/auth_type').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_manila_config('neutron/auth_type').with_value('password')
         is_expected.to contain_manila_config('neutron/cafile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_manila_config('neutron/user_domain_name').with_value('Default')
+        is_expected.to contain_manila_config('neutron/project_domain_name').with_value('Default')
+        is_expected.to contain_manila_config('neutron/project_name').with_value('services')
         is_expected.to contain_manila_config('neutron/region_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('neutron/timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('neutron/endpoint_type').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_manila_config('neutron/username').with_value('neutron')
+        is_expected.to contain_manila_config('neutron/password').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('DEFAULT/network_plugin_ipv4_enabled').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('DEFAULT/network_plugin_ipv6_enabled').with_value('<SERVICE DEFAULT>')
-
-        # These should be added only when auth_type is 'password'
-        is_expected.not_to contain_manila_config('neutron/user_domain_name')
-        is_expected.not_to contain_manila_config('neutron/project_domain_name')
-        is_expected.not_to contain_manila_config('neutron/project_name')
-        is_expected.not_to contain_manila_config('neutron/username')
-        is_expected.not_to contain_manila_config('neutron/password')
       end
     end
 
@@ -28,7 +26,7 @@ describe 'manila::network::neutron' do
         {
           :insecure       => true,
           :auth_url       => 'http://127.0.0.2:5000/',
-          :auth_type      => 'password',
+          :auth_type      => 'v3password',
           :cafile         => '/etc/ssl/certs/ca.crt',
           :region_name    => 'RegionOne',
           :timeout        => 30,
@@ -41,10 +39,9 @@ describe 'manila::network::neutron' do
       end
 
       it 'configures manila neutron with overridden parameters' do
-      	is_expected.to contain_manila_config('DEFAULT/network_api_class').with_value('manila.network.neutron.neutron_network_plugin.NeutronNetworkPlugin')
         is_expected.to contain_manila_config('neutron/insecure').with_value(true)
         is_expected.to contain_manila_config('neutron/auth_url').with_value('http://127.0.0.2:5000/')
-        is_expected.to contain_manila_config('neutron/auth_type').with_value('password')
+        is_expected.to contain_manila_config('neutron/auth_type').with_value('v3password')
         is_expected.to contain_manila_config('neutron/cafile').with_value('/etc/ssl/certs/ca.crt')
         is_expected.to contain_manila_config('neutron/user_domain_name').with_value('Default')
         is_expected.to contain_manila_config('neutron/project_domain_name').with_value('Default')
